/*!
 * Joshfire Framework 0.9.1
 * http://framework.joshfire.com/
 *
 * Copyright 2011, Joshfire
 * Dual licensed under the GPL Version 2 and a Commercial license.
 * http://framework.joshfire.com/license
 *
 * Date: Thu Jun 07 12:38:42 2012
 */

define(['joshlib!class', 'joshlib!vendor/underscore', 'joshlib!vendor/jquery'], function(Class, _, $) {
  return Class(
    {

      options: null,
      terms: null,

      __constructor: function(options) {
        var self = this;
        var defaults = {
          'url': './Languages',
          'locale': self._detectLocale(),
          'format': 'json'
        };
        if(options) {
          self.options = _.defaults(options, defaults);
        }
        else {
          self.options = defaults;
        }

        if(self.options.locale.toLowerCase() == 'auto')
          self.options.locale = self._detectLocale();

        self.loadLanguage();
      },

      /**
      * Returns the first occurence of the key in the terms.
      **/
      T: function(key) {
        var self = this;

        if(typeof key !== 'string') return '';

        for(var k in self.terms) {
          if(self.terms.hasOwnProperty(k)) {
            if(key.toLowerCase() == k.toLowerCase()) {
              return self.terms[k];
            }
          }
        }
        return key;
      },

      /**
      * Loads a data file and store its contents
      * into memory. Can be used to dynamically
      * switch Languages. Forced as synchronous
      * (file access).
      **/
      loadLanguage: function(locale) {
        var self = this;

        if(!locale)
          locale = self.options.locale;
        else
          self.options.locale = locale;

        var fileUrl = self.options.url+'/'+self.options.locale+'.'+self.options.format;
        /**
        * Sync. Load the strings into memory. Not very pretty
        * but as of now it is enough.
        **/
        $.ajax({
          url: fileUrl,
          dataType: 'json',
          success: function(data) {
            self.terms = data.terms;
          },
          error: function(e, et, er) {
            console.log("localizer error : ", et);
          }
        });

      },

      /**
      * Search for tags with the data-translate attribute
      * and translate their content. The data-translate
      * attribute is removed, making it easier to call
      * it again should new content be added.
      **/
      translateStaticContent: function(scope) {
        var self = this;
        if(!scope)
          scope = '*';
        $('*[data-translate]', scope).each(function() {
          $(this).html(self.T($(this).html()));
        });
      },

      /**
      * Returns only the first
      **/
      _detectLocale: function() {
        var lan = (navigator.language) ? navigator.language : navigator.userLanguage;
        return (lan.split('-').length>1)?lan.split('-')[0]:lan;
      }
    }
  );
});
